# Hello Python World

> Marcell Biemann - 2021

All the best practices, design patterns, good manners and references of Python programming language, by me, until now.

```bash
$ pip install -U hello-python-world
```

```python
from hello_python_world import HelloPythonWorld

HelloPythonWorld().message() # -->> 'Hello Python World'

HelloPythonWorld('OPEN-SOURCE').message() # -->> 'Hello OPEN-SOURCE World'
```
